/*
 * Copyright (C) 2011 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
import junit.framework.TestCase;

import org.infinispan.Cache;
import org.infinispan.affinity.KeyAffinityService;
import org.infinispan.affinity.KeyAffinityServiceFactory;
import org.infinispan.affinity.RndKeyGenerator;
import org.infinispan.config.Configuration;
import org.infinispan.config.Configuration.CacheMode;
import org.infinispan.config.GlobalConfiguration;
import org.infinispan.manager.DefaultCacheManager;
import org.infinispan.manager.EmbeddedCacheManager;
import org.infinispan.transaction.lookup.GenericTransactionManagerLookup;

import java.util.concurrent.Executors;

/**
 * @author <a href="mailto:nfilotto@exoplatform.com">Nicolas Filotto</a>
 * @version $Id$
 *
 */
public class TestNearCache extends TestCase
{
   @SuppressWarnings({"deprecation", "rawtypes", "unchecked"})
   public void testConsistency() throws Exception
   {
      GlobalConfiguration gc = GlobalConfiguration.getClusteredDefault();
      gc.fluent().transport().addProperty("configurationFile", "udp.xml");
      Configuration c = new Configuration();
      c.fluent().clustering().mode(CacheMode.DIST_SYNC).hash().numOwners(1).transaction()
         .transactionManagerLookupClass(GenericTransactionManagerLookup.class);
      EmbeddedCacheManager cm1 = new DefaultCacheManager(gc, c);
      EmbeddedCacheManager cm2 = new DefaultCacheManager(gc, c);
      Cache cache1 = cm1.getCache();
      Cache cache2 = cm2.getCache();
      KeyAffinityService keyAffinityService =
         KeyAffinityServiceFactory.newLocalKeyAffinityService(cache1, new RndKeyGenerator(),
            Executors.newSingleThreadExecutor(), 100);
      Object localKey = keyAffinityService.getKeyForAddress(cm1.getAddress());

      cache1.put(localKey, "foo");
      assertEquals("foo", cache1.get(localKey));
      assertEquals("foo", cache2.get(localKey));
      cache1.put(localKey, "foo2");
      assertEquals("foo2", cache1.get(localKey));
      assertEquals("foo2", cache2.get(localKey));
      cache2.put(localKey, "foo3");
      assertEquals("foo3", cache1.get(localKey));
      assertEquals("foo3", cache2.get(localKey));
   }
}
